[Scummvm-git-logs] scummvm master -> 059cfbf69182f2a3f44fe1ab9680d012ce22884d

sev- sev at scummvm.org
Fri Jan 13 22:40:06 CET 2017


This automated email contains information about 3 new commits which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
485f26e4d6 SCUMM: Fix bug #4515 (Dr. Fred facing wrong way in lab cutscene)
c95b6a9f8d SCUMM: Fix bug #6817 (V1 Actors drawn 1 line too high)
059cfbf691 Merge pull request #875 from segrax/master


Commit: 485f26e4d6d60c48529f4b336dee05d7d70a855f
    https://github.com/scummvm/scummvm/commit/485f26e4d6d60c48529f4b336dee05d7d70a855f
Author: Robert Crossfield (robcrossfield at gmail.com)
Date: 2016-12-27T10:21:09+11:00

Commit Message:
SCUMM: Fix bug #4515 (Dr. Fred facing wrong way in lab cutscene)

Changed paths:
    engines/scumm/actor.cpp
    engines/scumm/script_v2.cpp


diff --git a/engines/scumm/script_v2.cpp b/engines/scumm/script_v2.cpp
index 88c26f8..c58127e 100644
--- a/engines/scumm/script_v2.cpp
+++ b/engines/scumm/script_v2.cpp
@@ -1131,9 +1131,6 @@ void ScummEngine_v2::o2_putActor() {
 	x = getVarOrDirectByte(PARAM_2);
 	y = getVarOrDirectByte(PARAM_3);
 
-	if (_game.id == GID_MANIAC && _game.version <= 1 && _game.platform != Common::kPlatformNES)
-		a->setFacing(180);
-
 	a->putActor(x, y);
 }
 


Commit: c95b6a9f8db08d57a9e6a553fd68ece00d777315
    https://github.com/scummvm/scummvm/commit/c95b6a9f8db08d57a9e6a553fd68ece00d777315
Author: Robert Crossfield (robcrossfield at gmail.com)
Date: 2016-12-27T10:21:23+11:00

Commit Message:
SCUMM: Fix bug #6817 (V1 Actors drawn 1 line too high)

Changed paths:
    engines/scumm/costume.cpp


diff --git a/engines/scumm/costume.cpp b/engines/scumm/costume.cpp
index 7470f13..dc29414 100644
--- a/engines/scumm/costume.cpp
+++ b/engines/scumm/costume.cpp
@@ -114,6 +114,10 @@ byte ClassicCostumeRenderer::mainRoutine(int xmoveCur, int ymoveCur) {
 	v1.x = _actorX;
 	v1.y = _actorY;
 
+	// V0/V1 games are off by 1
+	if (_vm->_game.version <= 1)
+		v1.y += 1;
+
 	if (use_scaling) {
 
 		/* Scale direction */


Commit: 059cfbf69182f2a3f44fe1ab9680d012ce22884d
    https://github.com/scummvm/scummvm/commit/059cfbf69182f2a3f44fe1ab9680d012ce22884d
Author: Eugene Sandulenko (sev at scummvm.org)
Date: 2017-01-13T22:40:02+01:00

Commit Message:
Merge pull request #875 from segrax/master

SCUMM: V0/V1: Fix two graphical issues

Changed paths:
    engines/scumm/actor.cpp
    engines/scumm/costume.cpp
    engines/scumm/script_v2.cpp







More information about the Scummvm-git-logs mailing list
diff --git a/engines/scumm/actor.cpp b/engines/scumm/actor.cpp
index f09729a..8465526 100644
--- a/engines/scumm/actor.cpp
+++ b/engines/scumm/actor.cpp
@@ -1510,10 +1510,11 @@ void Actor::putActor(int dstX, int dstY, int newRoom) {
 		((Actor_v0 *)this)->_newWalkBoxEntered = false;
 		((Actor_v0 *)this)->_CurrentWalkTo = _pos;
 		((Actor_v0 *)this)->_NewWalkTo = _pos;
+	}
 
-		// V0 always sets the actor to face the camera upon entering a room
+	// V0-V1 Maniac always sets the actor to face the camera upon entering a room
+	if (_vm->_game.id == GID_MANIAC && _vm->_game.version <= 1 && _vm->_game.platform != Common::kPlatformNES)
 		setDirection(oldDirToNewDir(2));
-	}
 }
 
 static bool inBoxQuickReject(const BoxCoords &box, int x, int y, int threshold) {